pub struct NamespaceSpec {
pub finalizers: Option<Vec<String>>,
}Expand description
NamespaceSpec describes the attributes on a Namespace.
Fields
finalizers: Option<Vec<String>>Finalizers is an opaque list of values that must be empty to permanently remove object from storage. More info: https://kubernetes.io/docs/tasks/administer-cluster/namespaces/