pub struct PersistentVolumeClaim {
pub metadata: ObjectMeta,
pub spec: Option<PersistentVolumeClaimSpec>,
pub status: Option<PersistentVolumeClaimStatus>,
}Expand description
PersistentVolumeClaim is a user’s request for and claim to a persistent volume
Fields
metadata: ObjectMetaStandard object’s metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
spec: Option<PersistentVolumeClaimSpec>spec defines the desired characteristics of a volume requested by a pod author. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistentvolumeclaims
status: Option<PersistentVolumeClaimStatus>status represents the current information/status of a persistent volume claim. Read-only. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistentvolumeclaims