pub struct PersistentVolumeClaimStatus {
pub access_modes: Option<Vec<String>>,
pub allocated_resources: Option<BTreeMap<String, Quantity>>,
pub capacity: Option<BTreeMap<String, Quantity>>,
pub conditions: Option<Vec<PersistentVolumeClaimCondition>>,
pub phase: Option<String>,
pub resize_status: Option<String>,
}Expand description
PersistentVolumeClaimStatus is the current status of a persistent volume claim.
Fields
access_modes: Option<Vec<String>>accessModes contains the actual access modes the volume backing the PVC has. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes-1
allocated_resources: Option<BTreeMap<String, Quantity>>allocatedResources is the storage resource within AllocatedResources tracks the capacity allocated to a PVC. It may be larger than the actual capacity when a volume expansion operation is requested. For storage quota, the larger value from allocatedResources and PVC.spec.resources is used. If allocatedResources is not set, PVC.spec.resources alone is used for quota calculation. If a volume expansion capacity request is lowered, allocatedResources is only lowered if there are no expansion operations in progress and if the actual volume capacity is equal or lower than the requested capacity. This is an alpha field and requires enabling RecoverVolumeExpansionFailure feature.
capacity: Option<BTreeMap<String, Quantity>>capacity represents the actual resources of the underlying volume.
conditions: Option<Vec<PersistentVolumeClaimCondition>>conditions is the current Condition of persistent volume claim. If underlying persistent volume is being resized then the Condition will be set to ‘ResizeStarted’.
phase: Option<String>phase represents the current phase of PersistentVolumeClaim.
resize_status: Option<String>resizeStatus stores status of resize operation. ResizeStatus is not set by default but when expansion is complete resizeStatus is set to empty string by resize controller or kubelet. This is an alpha field and requires enabling RecoverVolumeExpansionFailure feature.