pub struct SecretReference {
pub name: Option<String>,
pub namespace: Option<String>,
}Expand description
SecretReference represents a Secret Reference. It has enough information to retrieve secret in any namespace
Fields
name: Option<String>name is unique within a namespace to reference a secret resource.
namespace: Option<String>namespace defines the space within which the secret name must be unique.